@@ -2,7 +2,7 @@ from typing import Tuple, Optional
 from urllib import request as ulreq
 from PIL import ImageFile
  
-def img_shape_from_url(uri)->Tuple[Optional[int],Optional[int]]:
+def img_shape_from_url(uri:str)->Tuple[Optional[int],Optional[int]]:
     """return width, height of the image"""
     # get file size *and* image size (None if not known)
     file = ulreq.urlopen(uri)
@@ -14,7 +14,7 @@ def img_shape_from_url(uri)->Tuple[Optional[int],Optional[int]]:
         data = file.read(1024)
         if not data:
             break
-        p.feed(data)
+        p.feed(data) #type: ignore
         if p.image:
             return p.image.size
             break
