@@ -1,11 +1,15 @@
 from typing import Any, Dict, List, Optional
+from pydantic import Field
 import deeplabel.client
 import deeplabel
 from deeplabel.exceptions import InvalidIdError
 import deeplabel.infer.gallery.gallery_tasks
-from deeplabel.basemodel import DeeplabelBase
+from deeplabel.basemodel import DeeplabelBase, MixinConfig
 
 
+class ImageResolution(MixinConfig):
+    height: Optional[int]
+    width: Optional[int]
 class Image(DeeplabelBase):
     gallery_id: str
     project_id:str
@@ -13,6 +17,7 @@ class Image(DeeplabelBase):
     image_url:str
     name:str
     parent_folder_id:Optional[str]
+    resolution:ImageResolution = Field(default_factory=ImageResolution) #type: ignore
 
     @classmethod
     def from_search_params(cls, params:Dict[str, Any], client: "deeplabel.client.BaseClient") -> List["Image"]:
@@ -30,4 +35,4 @@ class Image(DeeplabelBase):
 
     @classmethod
     def from_gallery_and_project_id(cls, gallery_id:str, project_id:str, client: "deeplabel.client.BaseClient")->List["Image"]:
-        return cls.from_search_params({"galleryId":gallery_id,'projectId':project_id}, client=client)
+        return cls.from_search_params({"galleryId":gallery_id,'projectId':project_id, "limit":"-1"}, client=client)
