@@ -70,8 +70,8 @@ class Gallery(DeeplabelBase):
     @property
     def images(self)->List["deeplabel.label.gallery.images.Image"]:
         """Get Images of the Gallery"""
-        return deeplabel.label.gallery.images.Image.from_gallery_id(
-            self.gallery_id, self.client
+        return deeplabel.label.gallery.images.Image.from_gallery_and_project_id(
+            self.gallery_id, self.project_id, self.client
         )
     
     @classmethod
